@@ -6,8 +6,7 @@ use crate::entities::errors::ConfigError;
 pub struct ConfigFieldSchema<Config> {
     pub name: &'static str,
     pub description: &'static str,
-    pub default_value: String,
-    // pub current_value: String,
+    pub default_value: Option<String>,
     pub setter: Box<dyn Fn(&mut Config, &str) -> Result<(), ConfigError>>,
     pub getter: Box<dyn Fn(&Config) -> String>,
 }
@@ -15,10 +14,24 @@ pub struct ConfigFieldSchema<Config> {
 pub struct ConfigFieldState {
     pub name: &'static str,
     pub description: &'static str,
-    pub default_value: String,
+    pub default_value: Option<String>,
     pub current_value: String,
 }
 
+fn set_default<Config>(
+    config: &mut Config,
+    field: &ConfigFieldSchema<Config>,
+) -> Result<(), ConfigError> {
+    if let Some(ref default) = field.default_value {
+        (field.setter)(config, default)
+    } else {
+        Err(ConfigError::VarNotSet(
+            field.name.into(),
+            field.description.into(),
+        ))
+    }
+}
+
 pub fn build_config<Config>(
     config: &mut Config,
     fields: &[ConfigFieldSchema<Config>],
@@ -26,9 +39,10 @@ pub fn build_config<Config>(
     for field in fields {
         let name = field.name;
         match env::var(name) {
+            Ok(val) if val.is_empty() => set_default(config, field)?,
             Ok(val) => (field.setter)(config, &val)?,
-            Err(VarError::NotPresent) => (field.setter)(config, &field.default_value)?,
-            _ => return Err(ConfigError::InvalidVar(name.to_string())),
+            Err(VarError::NotPresent) => set_default(config, field)?,
+            _ => return Err(ConfigError::InvalidVar(name.into())),
         };
     }
     Ok(())
@@ -58,7 +72,7 @@ impl<Config> ConfigFieldSchema<Config> {
     >(
         name: &'static str,
         description: &'static str,
-        default: T,
+        default: Option<T>,
         setter: Setter,
         getter: Getter,
     ) -> ConfigFieldSchema<Config> {
@@ -73,7 +87,7 @@ impl<Config> ConfigFieldSchema<Config> {
         ConfigFieldSchema {
             name,
             description,
-            default_value: default.to_string(),
+            default_value: default.map(|x| x.to_string()),
             setter,
             getter,
         }
