@@ -42,8 +42,21 @@ impl UseCaseError {
 #[derive(Debug)]
 pub enum ConfigError {
     InvalidVar(String),
+    VarNotSet(String, String),
 }
 
-impl_error!(ConfigError);
+impl std::fmt::Display for ConfigError {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::InvalidVar(name) => write!(f, "Invalid var \"{}\"", name),
+            Self::VarNotSet(name, description) => {
+                write!(f, "Var not set \"{}\" ({})", name, description)
+            }
+        }
+    }
+}
+
+impl std::error::Error for ConfigError {}
+
 impl_error!(CliArgError);
 impl_error!(UseCaseError);
