@@ -46,3 +46,26 @@ pub trait IRequestEnum: Sized + Copy + 'static {
         format!("{:?}", keys)
     }
 }
+
+pub trait IEnumValue<T: 'static + Sized + Copy + Eq>: Sized + Copy + Eq + 'static {
+    const ALL: &'static [(Self, T)];
+
+    fn to_value(self) -> T {
+        for (key, item) in Self::ALL {
+            if *key == self {
+                return *item
+            }
+        }
+        unreachable!()
+    }
+
+    fn from_value(value: T) -> Option<Self> {
+        for (key, check) in Self::ALL {
+            if *check == value {
+                return Some(*key)
+            }
+        }
+        None
+    }
+}
+
